package com.landray.kmss.sys.attachment.model;

import com.landray.kmss.util.ResourceUtil;
import com.landray.kmss.util.StringUtil;
import com.landray.kmss.sys.cluster.interfaces.message.IMessage;
import com.landray.kmss.sys.attachment.cluster.HistoryVersionConfigMessage;
import com.landray.kmss.sys.cluster.interfaces.MessageCenter;
import com.landray.kmss.sys.attachment.plugin.HistoryVersionPlugin;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.LoggerFactory;
import org.slf4j.Logger;
import com.landray.kmss.sys.appconfig.model.BaseAppConfig;

public class SysAttMainHistoryConfig extends BaseAppConfig
{
    private static final Logger logger;
    
    static {
        logger = LoggerFactory.getLogger(SysAttMainHistoryConfig.class);
    }
    
    public SysAttMainHistoryConfig() throws Exception {
        this.initDefaultValue("attClearEnable", "false");
        this.initDefaultValue("attClearCount", "500");
        this.initDefaultValue("attKeepDays", "90");
        this.initDefaultValue("rootType", "0");
    }
    
    private void initDefaultValue(final String key, final String value) {
        if (StringUtils.isEmpty((CharSequence)this.getValue(key))) {
            this.setValue(key, value);
        }
    }
    
    public void save() throws Exception {
        super.save();
        HistoryVersionPlugin.resetEnabledModelsMap(this.getAttHistoryConfigEnableModules());
        MessageCenter.getInstance().sendToOther((IMessage)new HistoryVersionConfigMessage(this.getAttHistoryConfigEnableModules()));
    }
    
    public static SysAttMainHistoryConfig newInstance() {
        SysAttMainHistoryConfig config = null;
        try {
            config = new SysAttMainHistoryConfig();
        }
        catch (final Exception e) {
            SysAttMainHistoryConfig.logger.error(e.toString());
        }
        return config;
    }
    
    public String getAttHistoryEnable() {
        String attHistoryEnable = this.getValue("attHistoryEnable");
        if (StringUtil.isNull(attHistoryEnable)) {
            attHistoryEnable = "";
        }
        return attHistoryEnable;
    }
    
    public String getAttClearEnable() {
        String attClearEnable = this.getValue("attClearEnable");
        if (StringUtil.isNull(attClearEnable)) {
            attClearEnable = "false";
        }
        return attClearEnable;
    }
    
    public String getAttClearCount() {
        String attClearCount = this.getValue("attClearCount");
        if (StringUtil.isNull(attClearCount)) {
            attClearCount = "500";
        }
        return attClearCount;
    }
    
    public String getAttKeepDays() {
        String attKeepDays = this.getValue("attKeepDays");
        if (StringUtil.isNull(attKeepDays)) {
            attKeepDays = "90";
        }
        return attKeepDays;
    }
    
    public String getRootType() {
        String rootType = this.getValue("rootType");
        if (StringUtil.isNull(rootType)) {
            rootType = "0";
        }
        return rootType;
    }
    
    public String getRootPath() {
        String rootPath = this.getValue("rootPath");
        if (StringUtil.isNull(rootPath)) {
            rootPath = "";
        }
        return rootPath;
    }
    
    public String getAttHistoryConfigEnableModules() {
        String attHistoryConfigEnableModules = this.getValue("attHistoryConfigEnableModules");
        if (StringUtil.isNull(attHistoryConfigEnableModules)) {
            attHistoryConfigEnableModules = "";
        }
        return attHistoryConfigEnableModules;
    }
    
    public String getJSPUrl() {
        return "/sys/attachment/sys_att_main/sysAttMainHistory_config.jsp";
    }
    
    public String getModelDesc() {
        return ResourceUtil.getString("sys-attachment:sysAttMain.view.history.config");
    }
}
